<?php
function wosmpl_leaflet_activate() {
    wp_enqueue_script('leaflet-js', plugin_dir_url( dirname( __FILE__ ) ) . 'public/js/leaflet.js', array( 'jquery' ), '1.3.4', false);
    wp_enqueue_script('markercluster-js', plugin_dir_url( dirname( __FILE__ ) ) . 'public/js/leaflet.markercluster-src.js', array( 'jquery' ), '1.3.4', false);
    wp_enqueue_style( 'leaflet-css', plugin_dir_url ( dirname( __FILE__ ) ) . 'public/css/leaflet.css');
    wp_enqueue_style( 'marker-cluster-css', plugin_dir_url ( dirname( __FILE__ ) ) . 'public/css/MarkerCluster.css');
    wp_enqueue_style( 'marker-cluster-default-css', plugin_dir_url ( dirname( __FILE__ ) ) . 'public/css/MarkerCluster.Default.css');

}

function wosmpl_pages_with_shortcode($shortcode, $args = array()) {
    if(!shortcode_exists($shortcode)) {
        // shortcode was not registered (yet?)
        return null;
    }

    // replace get_pages with get_posts
    // if you want to search in posts
    $pages = get_pages($args);
    $list = array();

    foreach($pages as $page) {
        if(has_shortcode($page->post_content, $shortcode)) {
            $list[] = $page;
        }
    }

    return $list;
}

function wosmpl_get_cat_marker_icon($cat_id){
    //get_option is caching result
    $cat_icon_path = get_option('wosmpl_cat_icon_path');
    $cat_icon_name_prefix = get_option('wosmpl_cat_icon_name_prefix');
    return  $cat_icon_path . $cat_icon_name_prefix . $cat_id . '.png';
}
function wosmpl_get_categories_with_nb(){
    $geo_cats = get_option('wosmpl_geo_cats', []);
    $contents = wosmpl_get_geolocalized_contents();

    foreach ($contents as $c) {

        if ($c->type == 'wosmpl_partners') {
            for($i=0;$i < count($geo_cats);$i++) {
             if ($geo_cats[$i]['id'] == $c->cat) {
                if (!isset($geo_cats[$i]['nb'])) {
                    $geo_cats[$i]['nb'] = 1;
                } else {
                    $geo_cats[$i]['nb']++;
                }
                break;
             }
            }
        }
        
    }

    return $geo_cats;
}

/*
* All partner's retreived content is reordered 
* to be returned an associative array 
* in which keys are categories id
*/
function wosmpl_get_array_by_category($contents) {
    $result = [];
    $tmp_result = [];
    $geo_cats = get_option('wosmpl_geo_cats', []);
    $named_cats = [];
    foreach ($geo_cats as $gc) {
        $named_cats[$gc['id']] = $gc['name'];
    }
    foreach ($contents as $c) {
        if ($c->cat > 0) {
            if (!isset($tmp_result[$c->cat])) {
                $tmp_result[$c->cat] = [];
            }
            $tmp_result[$c->cat][] = $c;
        }
        
    }
    //sort by contents size
    usort($tmp_result,function($a,$b) {
        if (count($a) == count($b)) {
            return 0;
        }
        return (count($a) > count($b)) ? -1 : 1;
        
    });
    // Set result with cat name keys
    foreach ($tmp_result as $contents) {
        $fc = $contents[0];
        $result[$named_cats[$fc->cat]] = ['id'=>$fc->cat,
                                          'contents'=>$contents];
    }
    //var_dump($result);
    return $result;
}

function wosmpl_get_map_url(){
    $options = get_option( 'wosmpl_options' );
    $map_url = '';
    if (isset($options['wosmpl_main_map_page_id'])) {
        $p_id = $options['wosmpl_main_map_page_id'];
        if ($p_id > 0) {
            $map_url = get_permalink($p_id);
        }
    }
    return $map_url;
}

/*
* Function returning HTML code of Partners categories (with or without map link url) 
*/
function wosmpl_get_categories_ul($ul_class='sub-menu wosmpl-cat',$with_map_link=FALSE) {
    $map_url = wosmpl_get_map_url();
    $cats = wosmpl_get_categories_with_nb();
    $o = '';
    if (count($cats) > 0) {
        $o = '<ul class="'.$ul_class.'">';

        foreach ($cats as $cat) {
            if ($cat['nb'] > 0) {
                $img_url = wosmpl_get_cat_marker_icon($cat['id']);
                $li_open = '<li>';
                $img_width = '50';
                if ($ul_class =='sub-menu') {
                    $li_open = '<li class="menu-item">';
                    $img_width = '35';
                }
                $o .= $li_open;
                $o .= '<img src="'.$img_url.'" width="'.$img_width.'" /> ';
                $o .= '<span>('.$cat['nb'].')</span>';
                if ($map_url != '') {
                    $o .= ' <a href="'.$map_url.'?code_categorie='.$cat['id'].'" >'.$cat['name'].'</a>';
                }
                
                $o .= '</li>';
            }
            
        }
        $o .= '</ul>';
        if ($map_url != '' && $with_map_link === TRUE) {
            $o .= '<a href="'.$map_url.'">Carte partenaire</a>';
        }
        
        

    } 
    return $o;   
}
